@@ -38,7 +38,7 @@ CREATE TABLE `api` (
 
 LOCK TABLES `api` WRITE;
 /*!40000 ALTER TABLE `api` DISABLE KEYS */;
-INSERT INTO `api` VALUES (3,'ulliS-API','TYD7+yl6wXjIgzvpH0DSjuclaUFptiySk10G7CaRLQtTA=='),(82,'ulliS-API','ABCnc+yl6wXjIgzvpH0DSjuclaUFptiySk10G7CaRLQtTA=='),(100,'ulliS-API','q3eknSKC9uGLPXfmdXjkiFR+by1OSr4+Z+/aZ24BFmOpNA=='),(111,'ulliS-API','e109sWV4bHB3UTdF3sb/JNRumP/3pM/7O2lOUsGfU2wYZg=='),(112,'ulliS-API','n6GB0CWyt1yg1fxj6bJj0cQMrQKcC15BuZcDWovh7w+XGw=='),(113,'chic-API','o4IpRzw0^r5bhE8^vlPeto4IpRzw0^r5bhE8^v#glPLet'),(127,'ulliS-API','82QdnLCt/j4pcpWDAwurAwGOJB6ZDGF4Sbj2HloNKV3Ujg=='),(128,'ulliS-API','dpK0nvECx1JrftMg3QhKhIVuE7syPjzfbRdgqbFwkIBpcQ=='),(129,'ulliS-API','PRTBJJOMtzbXT2u2A7RMbLp002pUoeebIVCcw26HCwMJ2A=='),(130,'ulliS-API','DfZnBjWhupJnJX2Rb9xSZr97SWOTFV8WB7zx4rF4csPeOw=='),(131,'ulliS-API','lFs9CiPwJ391aKGa57CvC9+Qmy+r4j5++8NcYHgkVZyJQw==');
+INSERT INTO `api` VALUES (3,'ulliS-API','TYD7+yl6wXjIgzvpH0DSjuclaUFptiySk10G7CaRLQtTA=='),(100,'ulliS-API','q3eknSKC9uGLPXfmdXjkiFR+by1OSr4+Z+/aZ24BFmOpNA=='),(112,'ulliS-API','n6GB0CWyt1yg1fxj6bJj0cQMrQKcC15BuZcDWovh7w+XGw=='),(113,'chic-API','o4IpRzw0^r5bhE8^vlPeto4IpRzw0^r5bhE8^v#glPLet'),(130,'ulliS-API','DfZnBjWhupJnJX2Rb9xSZr97SWOTFV8WB7zx4rF4csPeOw=='),(131,'ulliS-API','lFs9CiPwJ391aKGa57CvC9+Qmy+r4j5++8NcYHgkVZyJQw==');
 /*!40000 ALTER TABLE `api` ENABLE KEYS */;
 UNLOCK TABLES;
 
@@ -63,7 +63,7 @@ CREATE TABLE `clients` (
 
 LOCK TABLES `clients` WRITE;
 /*!40000 ALTER TABLE `clients` DISABLE KEYS */;
-INSERT INTO `clients` VALUES (3,'Le nom de votre hôpital','https://demo.ullisapp.fr/wp-json'),(82,'CHI Mont de Marsan Pays des Sources','https://mont-de-marsan.ullisapp.fr/wp-json'),(100,'GH Seclin Carvin','https://seclin-carvin.ullisapp.fr/wp-json'),(111,'CH Saint-Brieuc','https://saint-brieuc.ullisapp.fr/wp-json'),(112,'dev','https://dev.ullisapp.fr/wp-json'),(113,'CHIC Paramédicaux','https://paramedicaux.interludesante.com/wp-json'),(127,'Hôpitaux de Saint-Maurice ','https://hopitaux-saint-maurice.ullisapp.fr/wp-json'),(128,'Centre hospitalier des Murets','https://ch-murets.ullisapp.fr/wp-json'),(129,'Hôpital Fondation Rothschild','https://FOR.ullisapp.fr/wp-json'),(130,'test','https://test.ullisapp.fr/wp-json'),(131,'Hôpitaux Saint-Joseph & Marie-Lannelongue','https://ghpsj.ullisapp.fr/wp-json'),(132,'testoto','https://testoto.ullisapp.fr/wp-json');
+INSERT INTO `clients` VALUES (3,'Le nom de votre hôpital','https://demo.ullisapp.fr/wp-json'),(100,'GH Seclin Carvin','https://seclin-carvin.ullisapp.fr/wp-json'),(112,'dev','https://dev.ullisapp.fr/wp-json'),(113,'CHIC Paramédicaux','https://paramedicaux.interludesante.com/wp-json'),(130,'test','https://test.ullisapp.fr/wp-json'),(131,'Hôpitaux Saint-Joseph & Marie-Lannelongue','https://ghpsj.ullisapp.fr/wp-json'),(132,'testoto','https://testoto.ullisapp.fr/wp-json');
 /*!40000 ALTER TABLE `clients` ENABLE KEYS */;
 UNLOCK TABLES;
 
@@ -89,7 +89,7 @@ CREATE TABLE `codes` (
 
 LOCK TABLES `codes` WRITE;
 /*!40000 ALTER TABLE `codes` DISABLE KEYS */;
-INSERT INTO `codes` VALUES ('interlude',3),('CHI40#2025',82),('CHInov#2022',82),('montDeMarsan',82),('EXT_01_2026',100),('Ghsc_5962',100),('INT_11_2025',100),('medecin',111),('stbrieuc',111),('dev',112),('CHIC',113),('Stmaurice94',127),('Chmurets94',128),('FOR2023',129),('FORPROVISOIRE',129),('FHSJ052025!',131),('FHSJ112024*',131),('FHSJ112025?',131),('GHPSJ2024',131),('HML2024',131),('SJML052024*',131);
+INSERT INTO `codes` VALUES ('interlude',3),('EXT_01_2026',100),('Ghsc_5962',100),('INT_11_2025',100),('dev',112),('CHIC',113),('FHSJ052025!',131),('FHSJ112024*',131),('FHSJ112025?',131),('GHPSJ2024',131),('HML2024',131),('SJML052024*',131);
 /*!40000 ALTER TABLE `codes` ENABLE KEYS */;
 UNLOCK TABLES;
 
@@ -129,4 +129,4 @@ UNLOCK TABLES;
 /*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
 /*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;
 
--- Dump completed on 2026-01-26  3:00:01
+-- Dump completed on 2026-01-27  3:00:01
